//
//  ViewController.m
//  TextMapbox
//
//  Created by Andrew Gubanov on 27/05/16.
//  Copyright © 2016 Andrew Gubanov. All rights reserved.
//

#import "ViewController.h"
#import "StayMapCallout.h"
@import Mapbox;
@import MapKit;
#import "StayAnnotation.h"

@interface ViewController () <MGLMapViewDelegate>
@property (nonatomic, strong) MGLMapView *mapView;
@end

@implementation ViewController

- (void)viewDidLoad {
    [super viewDidLoad];
    self.mapView = [[MGLMapView alloc] initWithFrame:self.view.bounds styleURL:[MGLStyle lightStyleURLWithVersion:9]];
    self.mapView.maximumZoomLevel = 16.0f;
    self.mapView.autoresizingMask = UIViewAutoresizingFlexibleWidth | UIViewAutoresizingFlexibleHeight;
    self.mapView.tintColor = [UIColor darkGrayColor];
    [self.view insertSubview:self.mapView atIndex:0];
    
    // Set the map view‘s delegate property
    self.mapView.delegate = self;
    
    StayAnnotation *annotation = [[StayAnnotation alloc] init];
    annotation.coordinate = CLLocationCoordinate2DMake(10.0f, 0.0f);
    annotation.title = @"Hello world!";

    [self.mapView addAnnotations:@[annotation]];   
}

- (BOOL)mapView:(MGLMapView *)mapView annotationCanShowCallout:(id <MGLAnnotation>)annotation {
    // Always allow callouts to popup when annotations are tapped
    return YES;
}

- (UIView<MGLCalloutView> *)mapView:(__unused MGLMapView *)mapView calloutViewForAnnotation:(id<MGLAnnotation>)annotation
{
    // Only show callouts for `Hello world!` annotation
    if ([annotation respondsToSelector:@selector(title)]
        && [annotation.title isEqualToString:@"Hello world!"])
    {
        // Instantiate and return our custom callout view
        StayMapCallout *calloutView = [[StayMapCallout alloc] init];
        calloutView.representedObject = annotation;
        return calloutView;
    }
    return nil;
}

@end
